package com.ruoyi.model.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.model.domain.AppletTask;
import com.ruoyi.model.domain.AppletTaskUser;

import java.util.List;

/**
 * 任务中心Service接口
 *
 * @author daixiande
 */
public interface IAppletTaskUserService extends IService<AppletTaskUser> {
    /**
     * 查询任务中心
     *
     * @param id 任务中心主键
     * @return 任务中心
     */
    AppletTaskUser selectAppletTaskById(Long id);

    /**
     * 查询任务中心列表
     *
     * @param appletTask 任务中心
     * @return 任务中心集合
     */
    List<AppletTaskUser> selectAppletTaskList(AppletTaskUser appletTask);

    /**
     * 新增任务中心
     *
     * @param appletTask 任务中心
     * @return 结果
     */
    int insertAppletTask(AppletTaskUser appletTask);

    /**
     * 修改任务中心
     *
     * @param appletTask 任务中心
     * @return 结果
     */
    int updateAppletTask(AppletTaskUser appletTask);

    /**
     * 批量删除任务中心
     *
     * @param ids 需要删除的任务中心主键集合
     * @return 结果
     */
    int deleteAppletTaskByIds(Long[] ids);

    /**
     * 删除任务中心信息
     *
     * @param id 任务中心主键
     * @return 结果
     */
    int deleteAppletTaskById(Long id);
}
